@@ -321,7 +321,7 @@ class IntegralWindow(QtGui.QMainWindow):
         self.connect(aboutQtAction, QtCore.SIGNAL("triggered()"), QtGui.qApp.aboutQt)
 
     def showHelpBox(self):
-        QtGui.QMessageBox.information(self, self.tr("Help on Integral"),
+        QtGui.QMessageBox.about(self, self.tr("Help on Integral"),
             u'Mathematical operators : + - * / ** (power)\nExamples of functions : sqrt, exp, log, sin, acos\n' +\
             u'Examples of integrands : 1/(alpha*x+beta)**3, sin(kappa*x)**5, exp(omega*t**2)*t\n'+\
             u'Examples of variables : x, t, alpha, Omega\n'+u'Examples of limits : 0, -oo, pi/2, E, sqrt(1-y**2)\n'+\
@@ -333,7 +333,7 @@ class IntegralWindow(QtGui.QMainWindow):
         infoIntegral = self.tr("Calculation of integrals using ")
         infoPython = "Python v"+python_version()
         infoSymPy = "SymPy v"+__version__+" (http://sympy.org/)"
-        QtGui.QMessageBox.information(self, self.tr("About Integral"),
+        QtGui.QMessageBox.about(self, self.tr("About Integral"),
             'Integral v'+versionIntegral+' - LGPLv3 (C) 2011 Roberto Colistete Jr.\n'+\
             siteIntegral+infoIntegral+infoPython+" and "+infoSymPy+u'\n\n* In loving memory of my wife Lorena *')
 
